#!/usr/bin/perl

###############################################################################
#
# FileLister - an open source alternative for listing files/directories
#              with an easy navigateable interface.
#
# Copyright (c) by  Oliver Falk, June 2003
#                   oliver@linux-kernel.at
#
# Changes are welcome, but please inform me about those!
#
###############################################################################

###############################################################################
#
# $Id: search.pl,v 1.42 2004/11/26 09:17:57 oliver Exp $
#
# $Log: search.pl,v $
# Revision 1.42  2004/11/26 09:17:57  oliver
# * Name changed...
#
# Revision 1.41  2004/07/27 13:07:03  oliver
# + Add time_needed
#
# Revision 1.40  2004/07/06 13:03:34  oliver
# +) bumped: version number to 1.40
#
# Revision 1.1.1.1  2004/07/06 11:01:35  oliver
# * Initial import after cvs was lost
#
# Revision 1.4  2004/01/14 13:27:36  oliver
# + Bugfixed (ToolTips)
# * Layout changes in search results
#
# Revision 1.3  2004/01/12 13:15:54  oliver
# +/- Beautify HTML pages titles.
#
# Revision 1.2  2004/01/12 13:11:04  oliver
# + Add stuff for ToolTips, some bugfixes (as I can remember) :-)
#
# Revision 1.1  2004/01/12 10:44:48  oliver
# * Initial commit.
#
#
#
###############################################################################

# Load modules we use.
use strict;
use warnings;
use Time::HiRes qw/gettimeofday tv_interval/;
my $starttime = [gettimeofday];
require Template;
use CGI qw/:standard/;
use YAML::LoadFileCached;
use File::Basename;

# Set Version - comes from CVS.
(our $VERSION) = '$Revision: 1.42 $' =~ /([\d.]+)/;

# Create a new TT2 object.
my $tt = Template->new;

# Set static variable configfile and load it using YAML.
my $configfile = 'config/FileLister.yaml.conf';
my $config = LoadFileCached($configfile);

# Set variable hide_files - comes from config file.
my $hide_files = $config->{'listing_stuff'}->{'hide_files'};

my $search_string = param('search_string');
$search_string =~ s/\*/\.\*/;

# Some helper variables...
my @file_list;

if($search_string) {
    if(open(FH, "find $config->{'path_and_url_stuff'}->{'path'} -type f |")) {
        my @files;
        push @files, $_ foreach(<FH>);
        my $i = 0;
        foreach (sort @files) {
            if($_ =~ /$search_string/) {
                $i++;
                my %file;

                $file{'id'} = $i;

                $file{'filename'} = $_;
                $file{'filename'} =~ s/$config->{'path_and_url_stuff'}->{'path'}//;

                $file{'directory'} = dirname($file{'filename'});

                if($config->{'path_and_url_stuff'}->{'enable-ftp-download'}) {
                  $file{url_ftp}   = a({-href=>"$config->{'path_and_url_stuff'}->{'ftp_url'}$file{'filename'}"}, "FTP");
                }
                if($config->{'path_and_url_stuff'}->{'enable-http-download'}) {
                  $file{url_http}  = a({-href=>"$config->{'path_and_url_stuff'}->{'http_url'}$file{'filename'}"}, "HTTP");
                }
                push @file_list, \%file;
            }
        }
    }
}

my $main_url = url();
$main_url =~ s/search.pl//;

$search_string = "" unless($search_string);

# Finally create a hash with all the data, we want to display...
my %main_data = ( title            => "FileLister Search Results $VERSION \@ ".url(),
                  version          => $VERSION,
                  stylesheet       => $config->{'style_stuff'}->{'stylesheet'},
                  bg_color         => $config->{'style_stuff'}->{'FileLister_BGColor'},
                  config           => $config,
                  file_list        => \@file_list,
                  main_url         => $main_url,
                  use_tooltips     => $config->{'style_stuff'}->{'Use_ToolTips'},
                  search_string    => $search_string,
                  dir_description  => 'Jump to the directory containing this file',
                  ftp_description  => 'Download this file using FTP',
                  http_description => 'Download this file using HTTP');

$main_data{time_needed} = tv_interval($starttime, [gettimeofday]);

# Hand it over to Template::Toolkit - I love that thingy. :-)
$tt->process('templates/search_result.tpl', \%main_data) || die $tt->error;

#use Data::Dumper;
#warn Dumper(%main_data);
